@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2017 - 2023 Avram Lubkin, All Rights Reserved
+# Copyright 2017 - 2024 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -483,12 +483,12 @@ class Counter(PrintableCounter):
         Args:
             elapsed(float): Time since started.
             bar_fields(bool): When False, only set fields for basic counter
+            force_float(bool): Coerces count fields to :py:class:`prefixed.Float`
 
         Returns:
             :py:class:`tuple`: list of subcounters and dictionary of additional fields
 
         Each subcounter in the list will be in a tuple of (subcounter, percentage)
-        Fields in the dictionary are addressed in the Format documentation of this class
 
         When `bar_fields` is False, only subcounter count, interval, and rate fields are set.
         percentage will be set to 0.0
@@ -674,6 +674,7 @@ class Counter(PrintableCounter):
             iterations (float): Absolute value of count change from start
             width (int): Width in columns to make progress bar
             elapsed(float): Time since started
+            force_float(bool): Coerces count fields to :py:class:`prefixed.Float`
 
         Returns:
             :py:class:`str`: Formatted progress bar
@@ -722,9 +723,9 @@ class Counter(PrintableCounter):
         barText = u''
 
         if subcounters:
-            block_count = [int(barWidth * fields['percentage_0'] / 100)]
-            partial_len = (barLen - 1) if fields['count_0'] else barLen
-            remaining = []
+            remainder, count = math.modf(barWidth * fields['percentage_0'] / 100)
+            block_count = [int(count)]
+            remaining = [(remainder, 0)]
 
             # Get full blocks for subcounters and preserve remainders
             for idx, entry in enumerate(subcounters, 1):
@@ -733,9 +734,11 @@ class Counter(PrintableCounter):
                 remaining.append((remainder, idx))
 
             # Until blocks are accounted for, add full blocks for highest remainders
-            remaining.sort()
-            while sum(block_count) < partial_len and remaining:
-                block_count[remaining.pop()[1]] += 1
+            if self._count == self.total:
+                remaining.sort()
+                while sum(block_count) < barLen and remaining:
+                    _, idx = remaining.pop()
+                    block_count[idx] += 1
 
             # Format partial bars
             for idx, subLen in reversed(list(enumerate(block_count))):
@@ -756,7 +759,7 @@ class Counter(PrintableCounter):
 
         # If bar isn't complete, add partial block and fill
         if barLen < barWidth:
-            if fields.get('count_0', self.count):
+            if self.count and not subcounters:
                 barText += self.series[int(round((complete - barLen) * (len(self.series) - 1)))]
                 partial_len += 1
             barText += self.series[0] * (barWidth - partial_len)
